%-------------------------------------------------------------------------------------------------------
% PURPOSE: "Backtesting Marginal Expected Shortfall and Related Systemic Risk Measures"
%           Banulescu, Hurlin, Leymarie, and Scaillet (2020)
%-------------------------------------------------------------------------------------------------------
% This code reproduces the figures of the paper using the numerical outputs when running the set 
% of codes in the folders "MediumTerm_Forecasts" and "ShortTerm_Forecasts".
%-------------------------------------------------------------------------------------------------------
% J. Leymarie, June 03, 2020.
% University of Vienna
%-------------------------------------------------------------------------------------------------------

%=========================================================%
%======    Figure 1 of the paper (main text)        ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_recursive_N=250
firm=[3 21 52 66];
uc_risk=uc_risk(:,firm);
p_uc_risk=p_uc_risk(:,firm);
p_uc_c=p_uc_c(:,firm);
p_uc_c_kernel=p_uc_c_kernel(:,firm);
MES=MES(:,firm);
SRISK=SRISK(:,firm);
level1=0.05;                                                         % Rejection threshold
SRISK_milliard=SRISK*10^-9;                                          % SRISK in millard of Dollars
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
%== UC backtest for AIG (corrected) ==%
subplot(2,2,1)                                             
yyaxis left                                                
plot(date,MES(:,1),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,1),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,1)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('AIG')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for BAC (corrected) ==%
subplot(2,2,2)                                             
yyaxis left                                                
plot(date,MES(:,2),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,2),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,2)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('BAC')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for JPM (corrected) ==%
subplot(2,2,3)                                             
yyaxis left                                                
plot(date,MES(:,3),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,3),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,3)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('JPM')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for LEH (corrected) ==%
subplot(2,2,4)                                             
yyaxis left                                                
plot(date,MES(:,4),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,4),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,4)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('LEH')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
suptitle('Figure 1: UC backtests for one-day risk forecast horizon (recursive estimation, n = 250)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);
   
%=========================================================%
%======    Figure 2 of the paper (main text)        ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_recursive_N=250
firm=[3 21 52 66];
p_ind_risk=squeeze(p_ind_risk(:,firm,:));
p_ind_c=squeeze(p_ind_c(:,firm,:));
p_ind_c_kernel=squeeze(p_ind_c_kernel(:,firm,:));
p_uc_c_kernel=p_uc_c_kernel(:,firm);
MES=MES(:,firm);
SRISK=SRISK(:,firm);
lag=5;                                                               % Lag choice for the IND test
level1=0.05;                                                         % Rejection threshold
SRISK_milliard=SRISK*10^-9;                                          % SRISK in millard of Dollars
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
%== IND backtest for AIG (corrected) ==%
subplot(2,2,1)                                             
yyaxis left                                                
plot(date,MES(:,1),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,1),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,1,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('AIG')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for BAC (corrected) ==%
subplot(2,2,2)                                             
yyaxis left                                                
plot(date,MES(:,2),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,2),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,2,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('BAC')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for JPM (corrected) ==%
subplot(2,2,3)                                             
yyaxis left                                                
plot(date,MES(:,3),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,3),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,3,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('JPM')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for LEH (corrected) ==%
subplot(2,2,4)                                             
yyaxis left                                                
plot(date,MES(:,4),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,4),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,4,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('LEH')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
suptitle('Figure 2: IND backtests for one-day risk forecast horizon (recursive estimation, n = 250, m = 5)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 3 of the paper (main text)        ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_recursive_N=250
level=0.05;                                                % Rejection threshold of null hypothesis
% UC tests :
m_uc_c=nb_firm-sum(isnan(p_uc_c),2);
m_uc_c_kernel=nb_firm-sum(isnan(p_uc_c_kernel),2);
% Rejection rate for uc test with bonferonni controling method
bonf_reject_rate_uc_c_kernel=sum(repmat(m_uc_c_kernel,1,nb_firm).*p_uc_c_kernel<level,2)./(nb_firm-sum(isnan(p_uc_c_kernel),2));
subplot(2,1,1)
bar(date,bonf_reject_rate_uc_c_kernel)
ylim([0 1])
grid on
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([datenum(first_year,1,2) datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
title('UC test')
lag=5;                                                     % Lag choice for the IND test
level=0.05;                                                % Rejection threshold of null hypothesis
% Number of firms's individual tests (belonging to the joint test)
% Ind tests :
m_ind_c_kernel=nb_firm-sum(isnan(p_ind_c_kernel(:,:,lag)),2);
% Rejection rate for ind test with bonferonni controling method
bonf_reject_rate_ind_c_kernel=sum(repmat(m_ind_c_kernel,1,nb_firm).*p_ind_c_kernel(:,:,lag)<level,2)./(nb_firm-sum(isnan(p_ind_c_kernel(:,:,lag)),2));
subplot(2,1,2)
bar(date,bonf_reject_rate_ind_c_kernel)
ylim([0 1])
grid on
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([datenum(first_year,1,2) datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
title('IND test')
suptitle('Figure 3: Rejection rates of UC and IND backtests (recursive estimation, n = 250, m = 5)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 4 of the paper (main text)        ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_recursive_N=500
level=0.05;                                                % Rejection threshold of null hypothesis
% UC tests :
m_uc_c=nb_firm-sum(isnan(p_uc_c),2);
m_uc_c_kernel=nb_firm-sum(isnan(p_uc_c_kernel),2);
% Rejection rate for uc test with bonferonni controling method
bonf_reject_rate_uc_c_kernel=sum(repmat(m_uc_c_kernel,1,nb_firm).*p_uc_c_kernel<level,2)./(nb_firm-sum(isnan(p_uc_c_kernel),2));
subplot(2,1,1)
bar(date,bonf_reject_rate_uc_c_kernel)
ylim([0 1])
grid on
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([datenum(first_year,1,2) datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
title('UC test')
lag=5;                                                     % Lag choice for the IND test
level=0.05;                                                % Rejection threshold of null hypothesis
% Number of firms's individual tests (belonging to the joint test)
% Ind tests :
m_ind_c_kernel=nb_firm-sum(isnan(p_ind_c_kernel(:,:,lag)),2);
% Rejection rate for ind test with bonferonni controling method
bonf_reject_rate_ind_c_kernel=sum(repmat(m_ind_c_kernel,1,nb_firm).*p_ind_c_kernel(:,:,lag)<level,2)./(nb_firm-sum(isnan(p_ind_c_kernel(:,:,lag)),2));
subplot(2,1,2)
bar(date,bonf_reject_rate_ind_c_kernel)
ylim([0 1])
grid on
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([datenum(first_year,1,2) datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
title('IND test')
suptitle('Figure 4: Rejection rates of UC and IND backtests (recursive estimation, n = 500, m = 5)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 6 of the paper (main text)        ======%
%=========================================================%

clear, clc,
load historical_h_rejection_rate_recursive_N=100
level=0.05;                                                % Rejection threshold of null hypothesis
start=17;                                                  % Number of period to be removed for plot (because NaN)
date=date(start:end);
p_uc_c_hac=p_uc_c_hac(start:end,:);
% Number of firms's individual tests (belonging to the joint test)
% UC tests :
m_uc_c_hac=nb_firm-sum(isnan(p_uc_c_hac),2);
% Rejection rate for uc test with bonferroni controling method
bonf_reject_rate_uc_c_hac=sum(repmat(m_uc_c_hac,1,nb_firm).*p_uc_c_hac<level,2)./(nb_firm-sum(isnan(p_uc_c_hac),2));
subplot(2,1,1)
bar(date,bonf_reject_rate_uc_c_hac)
ylim([0 1])
grid on
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([date(1)-35 datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
title('Recursive estimation')
clear, clc,
load historical_h_rejection_rate_rolling_T=500_N=100
level=0.05;                                                % Rejection threshold of null hypothesis
start=17;                                                  % Number of period to be removed for plot (because NaN)
date=date(start:end);
p_uc_c_hac=p_uc_c_hac(start:end,:);
% Number of firms's individual tests (belonging to the joint test)
% UC tests :
m_uc_c_hac=nb_firm-sum(isnan(p_uc_c_hac),2);
% Rejection rate for uc test with bonferroni controling method
bonf_reject_rate_uc_c_hac=sum(repmat(m_uc_c_hac,1,nb_firm).*p_uc_c_hac<level,2)./(nb_firm-sum(isnan(p_uc_c_hac),2));
subplot(2,1,2)
bar(date,bonf_reject_rate_uc_c_hac)
ylim([0 1])
grid on
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([date(1)-35 datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
title('Rolling estimation, T=500')
suptitle('Figure 6: Rejection rates of UC backtests (n = 100, h = 22, overlap of 11 days)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 7 of the paper (main text)        ======%
%=========================================================%

clear ; clc ; 
load historical_rejection_rate_recursive_N=250_dcovar
firm=[3 21 52 66];
limup1=1;
limup2=0.4;
uc_dcovar_risk=uc_dcovar_risk(:,firm);
puc_dcovar_risk=puc_dcovar_risk(:,firm);
puc_dcovar_ck=puc_dcovar_ck(:,firm);
dcovar_out=dcovar_out(:,firm);
covar1_out=covar1_out(:,firm);
covar2_out=covar2_out(:,firm);
puc_h1_risk=puc_h1_risk(:,firm);
puc_h2_risk=puc_h2_risk(:,firm);
puc_h1_c=puc_h1_c(:,firm);
puc_h2_c=puc_h2_c(:,firm);
level1=0.05;                                                             % Rejection threshold
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
%== UC backtest for AIG (corrected) ==%
subplot(2,2,1)                                             
plot(date,dcovar_out(:,1),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup1])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_dcovar_ck(i,1)<level1(1); shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('AIG')
mylegend=legend('Daily \Delta CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
%== UC backtest for BAC (corrected) ==%
subplot(2,2,2)                                             
plot(date,dcovar_out(:,2),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup2])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_dcovar_ck(i,2)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('BAC')
mylegend=legend('Daily \Delta CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
%== UC backtest for JPM (corrected) ==%
subplot(2,2,3)                                             
plot(date,dcovar_out(:,3),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup2])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_dcovar_ck(i,3)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('JPM')
mylegend=legend('Daily \Delta CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
%== UC backtest for LEH (corrected) ==%
subplot(2,2,4)  
plot(date,dcovar_out(:,4),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup2])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_dcovar_ck(i,4)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('LEH')
mylegend=legend('Daily \Delta CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
suptitle('Figure 7: UC backtests for Delta CoVaR (recursive estimation, n = 250)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 8 of the paper (main text)        ======%
%=========================================================%

clear ; clc ; 
load historical_rejection_rate_recursive_N=250_dcovar
firm=[3 21 52 66];
limup1=1;
limup2=0.4;
uc_dcovar_risk=uc_dcovar_risk(:,firm);
puc_dcovar_risk=puc_dcovar_risk(:,firm);
puc_dcovar_ck=puc_dcovar_ck(:,firm);
dcovar_out=dcovar_out(:,firm);
covar1_out=covar1_out(:,firm);
covar2_out=covar2_out(:,firm);
puc_h1_risk=puc_h1_risk(:,firm);
puc_h2_risk=puc_h2_risk(:,firm);
puc_h1_c=puc_h1_c(:,firm);
puc_h2_c=puc_h2_c(:,firm);
level1=0.05;                                                             % Rejection threshold
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
%== UC backtest for AIG (corrected) ==%
subplot(2,2,1)                                             
plot(date,-covar1_out(:,1),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup1])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_h1_c(i,1)<level1(1); shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('AIG')
mylegend=legend('Daily stressed CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
%== UC backtest for BAC (corrected) ==%
subplot(2,2,2)                                             
plot(date,-covar1_out(:,2),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup2])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_h1_c(i,2)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('BAC')
mylegend=legend('Daily stressed CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
%== UC backtest for JPM (corrected) ==%
subplot(2,2,3)                                             
plot(date,-covar1_out(:,3),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup2])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_h1_c(i,3)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('JPM')
mylegend=legend('Daily stressed CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
%== UC backtest for LEH (corrected) ==%
subplot(2,2,4)  
plot(date,-covar1_out(:,4),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup2])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_h1_c(i,4)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('LEH')
mylegend=legend('Daily stressed CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
suptitle('Figure 8: UC backtests for stressed CoVaR (recursive estimation, n = 250)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 9 of the paper (main text)        ======%
%=========================================================%

clear ; clc ; 
load historical_rejection_rate_recursive_N=250_dcovar
firm=[3 21 52 66];
limup1=1;
limup2=0.4;
uc_dcovar_risk=uc_dcovar_risk(:,firm);
puc_dcovar_risk=puc_dcovar_risk(:,firm);
puc_dcovar_ck=puc_dcovar_ck(:,firm);
dcovar_out=dcovar_out(:,firm);
covar1_out=covar1_out(:,firm);
covar2_out=covar2_out(:,firm);
puc_h1_risk=puc_h1_risk(:,firm);
puc_h2_risk=puc_h2_risk(:,firm);
puc_h1_c=puc_h1_c(:,firm);
puc_h2_c=puc_h2_c(:,firm);
level1=0.05;                                                             % Rejection threshold
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
%== UC backtest for AIG (corrected) ==%
subplot(2,2,1)                                             
plot(date,-covar2_out(:,1),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup1])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_h2_c(i,1)<level1(1); shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('AIG')
mylegend=legend('Daily median CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
%== UC backtest for BAC (corrected) ==%
subplot(2,2,2)                                             
plot(date,-covar2_out(:,2),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup2])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_h2_c(i,2)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('BAC')
mylegend=legend('Daily median CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
%== UC backtest for JPM (corrected) ==%
subplot(2,2,3)                                             
plot(date,-covar2_out(:,3),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup2])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_h2_c(i,3)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('JPM')
mylegend=legend('Daily median CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
%== UC backtest for LEH (corrected) ==%
subplot(2,2,4)  
plot(date,-covar2_out(:,4),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 limup2])
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_dcovar_risk),1);                                  
for i=1:length(uc_dcovar_risk);if puc_h2_c(i,4)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('LEH')
mylegend=legend('Daily median CoVaR','Rejection dates');
set(mylegend,'FontSize',8);
suptitle('Figure 9: UC backtests for median CoVaR (recursive estimation, n = 250)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 10 of the paper (main text)       ======%
%=========================================================%

clear ; clc ; 
load historical_rejection_rate_recursive_N=250_dcovar
level=0.05;                                                % Rejection threshold of null hypothesis
% Number of firms's individual tests (belonging to the joint test)
m_uc_risk=nb_firm-sum(isnan(puc_dcovar_risk),2);
m_uc_ck=nb_firm-sum(isnan(puc_dcovar_ck),2);
% Rejection rate with bonferroni controlling method
bonf_reject_rate_ucdcovar_ck=sum(repmat(m_uc_ck,1,nb_firm).*puc_dcovar_ck<level,2)./(nb_firm-sum(isnan(puc_dcovar_ck),2));
bonf_reject_rate_uc_h1_ck=sum(repmat(m_uc_risk,1,nb_firm).*puc_h1_c<level,2)./(nb_firm-sum(isnan(puc_h1_c),2));
bonf_reject_rate_uc_h2_ck=sum(repmat(m_uc_risk,1,nb_firm).*puc_h2_c<level,2)./(nb_firm-sum(isnan(puc_h2_c),2));
figure
subplot(3,1,1)
bar(date,bonf_reject_rate_ucdcovar_ck)
ylim([0 1])
grid on
title('\Delta CoVaR')
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([datenum(first_year,1,2) datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
subplot(3,1,2)
bar(date,bonf_reject_rate_uc_h1_ck)
ylim([0 1])
grid on
title('Stressed CoVaR')
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([datenum(first_year,1,2) datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
subplot(3,1,3)
bar(date,bonf_reject_rate_uc_h2_ck)
ylim([0 1])
grid on
title('Median CoVaR')
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([datenum(first_year,1,2) datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
suptitle('Figure 10: Rejection rates for Delta CoVaR, stressed, and median CoVaRs (recursive estimation, n =250)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0, 1, 1]);

%=========================================================%
%======    Figure 11 of the paper (main text)       ======%
%=========================================================%

clear ; clc ; 
load historical_rejection_rate_recursive_N=250
firm=[3 21 52 66];
alpha_adj=alpha_adj(:,firm);
MES=MES(:,firm);
MES_adj=MES_adj(:,firm);
LRMES=LRMES(:,firm);
LRMES_adj=LRMES_adj(:,firm);
SRISK=SRISK(:,firm)*10^-9;
SRISK_adj=SRISK_adj(:,firm)*10^-9;
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
indfirm=1;
subplot(2,2,1) 
plot(date,MES_adj(:,indfirm)-MES(:,indfirm),'color',[0 66 214] ./ 255,'LineWidth',1.2), hold on,
plot([732343 736695],[0 0],'--', 'color','black','LineWidth',1.2)
grid on,
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
mylegend=legend('$EWS_t(\alpha,\tilde{\alpha})$');
set(mylegend,'FontSize',8,'Interpreter','latex');
title('AIG')
indfirm=2;
subplot(2,2,2)
plot(date,MES_adj(:,indfirm)-MES(:,indfirm),'color',[0 66 214] ./ 255,'LineWidth',1.2), hold on,
plot([732343 736695],[0 0],'--', 'color','black','LineWidth',1.2)
grid on,
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
mylegend=legend('$EWS_t(\alpha,\tilde{\alpha})$');
set(mylegend,'FontSize',8,'Interpreter','latex');
title('BAC')
indfirm=3;
subplot(2,2,3)
plot(date,MES_adj(:,indfirm)-MES(:,indfirm),'color',[0 66 214] ./ 255,'LineWidth',1.2), hold on,
plot([732343 736695],[0 0],'--', 'color','black','LineWidth',1.2)
grid on,
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
mylegend=legend('$EWS_t(\alpha,\tilde{\alpha})$');
set(mylegend,'FontSize',8,'Interpreter','latex');
title('JPM')
indfirm=4;
subplot(2,2,4)
plot(date,MES_adj(:,indfirm)-MES(:,indfirm),'color',[0 66 214] ./ 255,'LineWidth',1.2), hold on,
plot([732343 736695],[0 0],'--', 'color','black','LineWidth',1.2)
grid on,
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
mylegend=legend('$EWS_t(\alpha,\tilde{\alpha})$');
set(mylegend,'FontSize',8,'Interpreter','latex');
title('LEH')
suptitle('Figure 11: EWSt for a panel of four firms (recursive estimation, n = 250)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 12 of the paper (main text)       ======%
%=========================================================%

clear ; clc ; 
load historical_rejection_rate_recursive_N=250
aggMES=nansum(MES,2);
aggMES_adj=nansum(MES_adj,2);
aggLRMES=nansum(LRMES,2);
aggLRMES_adj=nansum(LRMES_adj,2);
aggSRISK=nansum(SRISK,2)*10^-9;
aggSRISK_adj=nansum(SRISK_adj,2)*10^-9;
agg=aggMES;
agg_adj=aggMES_adj;
plot(date,agg_adj-agg,'color',[0 66 214] ./ 255,'LineWidth',1.2), hold on,
plot([732343 736695],[0 0],'--', 'color','black','LineWidth',1.2)
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
mylegend=legend('Aggregated $EWS_t(\alpha,\tilde{\alpha})$');
set(mylegend,'FontSize',8,'Interpreter','latex');
grid on
suptitle('Figure 12: Aggregated EWSt (recursive estimation, n = 250)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 13 of the paper (appendix J)      ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_recursive_N=500
firm=[3 21 52 66];
uc_risk=uc_risk(:,firm);
p_uc_risk=p_uc_risk(:,firm);
p_uc_c=p_uc_c(:,firm);
p_uc_c_kernel=p_uc_c_kernel(:,firm);
MES=MES(:,firm);
SRISK=SRISK(:,firm);
level1=0.05;                                                         % Rejection threshold
SRISK_milliard=SRISK*10^-9;                                          % SRISK in millard of Dollars
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
%== UC backtest for AIG (corrected) ==%
subplot(2,2,1)                                             
yyaxis left                                                
plot(date,MES(:,1),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,1),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,1)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('AIG')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for BAC (corrected) ==%
subplot(2,2,2)                                             
yyaxis left                                                
plot(date,MES(:,2),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,2),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,2)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('BAC')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for JPM (corrected) ==%
subplot(2,2,3)                                             
yyaxis left                                                
plot(date,MES(:,3),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,3),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,3)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('JPM')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for LEH (corrected) ==%
subplot(2,2,4)                                             
yyaxis left                                                
plot(date,MES(:,4),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,4),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,4)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('LEH')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
suptitle('Figure 13: UC backtests for one-day risk forecast horizon (recursive estimation, n = 500)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 14 of the paper (appendix J)      ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_rolling_T=500_N=250
firm=[3 21 52 66];
uc_risk=uc_risk(:,firm);
p_uc_risk=p_uc_risk(:,firm);
p_uc_c=p_uc_c(:,firm);
p_uc_c_kernel=p_uc_c_kernel(:,firm);
MES=MES(:,firm);
SRISK=SRISK(:,firm);
level1=0.05;                                                         % Rejection threshold
SRISK_milliard=SRISK*10^-9;                                          % SRISK in millard of Dollars
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
%== UC backtest for AIG (corrected) ==%
subplot(2,2,1)                                             
yyaxis left                                                
plot(date,MES(:,1),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,1),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,1)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('AIG')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for BAC (corrected) ==%
subplot(2,2,2)                                             
yyaxis left                                                
plot(date,MES(:,2),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,2),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,2)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('BAC')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for JPM (corrected) ==%
subplot(2,2,3)                                             
yyaxis left                                                
plot(date,MES(:,3),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,3),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,3)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('JPM')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for LEH (corrected) ==%
subplot(2,2,4)                                             
yyaxis left                                                
plot(date,MES(:,4),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,4),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,4)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('LEH')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
suptitle('Figure 14: UC backtests for one-day risk forecast horizon (rolling estimation, T = 500, n = 250)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 15 of the paper (appendix J)      ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_rolling_T=500_N=500
firm=[3 21 52 66];
uc_risk=uc_risk(:,firm);
p_uc_risk=p_uc_risk(:,firm);
p_uc_c=p_uc_c(:,firm);
p_uc_c_kernel=p_uc_c_kernel(:,firm);
MES=MES(:,firm);
SRISK=SRISK(:,firm);
level1=0.05;                                                         % Rejection threshold
SRISK_milliard=SRISK*10^-9;                                          % SRISK in millard of Dollars
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
%== UC backtest for AIG (corrected) ==%
subplot(2,2,1)                                             
yyaxis left                                                
plot(date,MES(:,1),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,1),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,1)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('AIG')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for BAC (corrected) ==%
subplot(2,2,2)                                             
yyaxis left                                                
plot(date,MES(:,2),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,2),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,2)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('BAC')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for JPM (corrected) ==%
subplot(2,2,3)                                             
yyaxis left                                                
plot(date,MES(:,3),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,3),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,3)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('JPM')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== UC backtest for LEH (corrected) ==%
subplot(2,2,4)                                             
yyaxis left                                                
plot(date,MES(:,4),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,4),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_uc_c_kernel(i,4)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4], 'edgecolor',[0.75,0.75,0.75])
hold on
title('LEH')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
suptitle('Figure 15: UC backtests for one-day risk forecast horizon (rolling estimation, T = 500, n = 500)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 16 of the paper (appendix J)      ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_recursive_N=500
firm=[3 21 52 66];
p_ind_risk=squeeze(p_ind_risk(:,firm,:));
p_ind_c=squeeze(p_ind_c(:,firm,:));
p_ind_c_kernel=squeeze(p_ind_c_kernel(:,firm,:));
p_uc_c_kernel=p_uc_c_kernel(:,firm);
MES=MES(:,firm);
SRISK=SRISK(:,firm);
lag=5;                                                               % Lag choice for the IND test
level1=0.05;                                                         % Rejection threshold
SRISK_milliard=SRISK*10^-9;                                          % SRISK in millard of Dollars
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
%== IND backtest for AIG (corrected) ==%
subplot(2,2,1)                                             
yyaxis left                                                
plot(date,MES(:,1),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,1),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,1,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('AIG')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for BAC (corrected) ==%
subplot(2,2,2)                                             
yyaxis left                                                
plot(date,MES(:,2),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,2),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,2,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('BAC')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for JPM (corrected) ==%
subplot(2,2,3)                                             
yyaxis left                                                
plot(date,MES(:,3),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,3),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,3,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('JPM')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for LEH (corrected) ==%
subplot(2,2,4)                                             
yyaxis left                                                
plot(date,MES(:,4),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,4),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,4,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('LEH')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
suptitle('Figure 16: IND backtests for one-day risk forecast horizon (recursive estimation, n = 500, m = 5)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 17 of the paper (appendix J)      ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_rolling_T=500_N=250
firm=[3 21 52 66];
p_ind_risk=squeeze(p_ind_risk(:,firm,:));
p_ind_c=squeeze(p_ind_c(:,firm,:));
p_ind_c_kernel=squeeze(p_ind_c_kernel(:,firm,:));
p_uc_c_kernel=p_uc_c_kernel(:,firm);
MES=MES(:,firm);
SRISK=SRISK(:,firm);
lag=5;                                                               % Lag choice for the IND test
level1=0.05;                                                         % Rejection threshold
SRISK_milliard=SRISK*10^-9;                                          % SRISK in millard of Dollars
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
%== IND backtest for AIG (corrected) ==%
subplot(2,2,1)                                             
yyaxis left                                                
plot(date,MES(:,1),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,1),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,1,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('AIG')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for BAC (corrected) ==%
subplot(2,2,2)                                             
yyaxis left                                                
plot(date,MES(:,2),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,2),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,2,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('BAC')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for JPM (corrected) ==%
subplot(2,2,3)                                             
yyaxis left                                                
plot(date,MES(:,3),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,3),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,3,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('JPM')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for LEH (corrected) ==%
subplot(2,2,4)                                             
yyaxis left                                                
plot(date,MES(:,4),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,4),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,4,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('LEH')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
suptitle('Figure 17: IND backtests for one-day risk forecast horizon (rolling estimation, T = 500, n = 250,m = 5)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 18 of the paper (appendix J)      ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_rolling_T=500_N=500
firm=[3 21 52 66];
p_ind_risk=squeeze(p_ind_risk(:,firm,:));
p_ind_c=squeeze(p_ind_c(:,firm,:));
p_ind_c_kernel=squeeze(p_ind_c_kernel(:,firm,:));
p_uc_c_kernel=p_uc_c_kernel(:,firm);
MES=MES(:,firm);
SRISK=SRISK(:,firm);
lag=5;                                                               % Lag choice for the IND test
level1=0.05;                                                         % Rejection threshold
SRISK_milliard=SRISK*10^-9;                                          % SRISK in millard of Dollars
% I set axis color to black manually
fig = figure;
left_color = [0 0 0];
right_color = [0 0 0];
set(fig,'defaultAxesColorOrder',[left_color; right_color]);
%== IND backtest for AIG (corrected) ==%
subplot(2,2,1)                                             
yyaxis left                                                
plot(date,MES(:,1),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,1),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,1,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('AIG')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for BAC (corrected) ==%
subplot(2,2,2)                                             
yyaxis left                                                
plot(date,MES(:,2),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,2),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,2,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('BAC')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for JPM (corrected) ==%
subplot(2,2,3)                                             
yyaxis left                                                
plot(date,MES(:,3),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,3),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,3,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('JPM')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
%== IND backtest for LEH (corrected) ==%
subplot(2,2,4)                                             
yyaxis left                                                
plot(date,MES(:,4),'color',[0 66 214] ./ 255,'LineWidth',2) 
ylim([0 0.6])
yyaxis right
plot(date,SRISK_milliard(:,4),'color',[222 28 19] ./ 255,'LineWidth',2) 
xlim([datenum(first_year,1,2) datenum(last_year+1,1,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,1,2);
datetick('x','yyyy','keeplimits','keepticks')
grid on
hold on
shade=NaN(length(uc_risk),1);                                  
for i=1:length(uc_risk);if p_ind_c_kernel(i,4,lag)<level1; shade(i)=150;end;end
shaded=bar(date,shade);shaded.FaceAlpha = 0.5;shaded.EdgeAlpha=0.5;
set(shaded,'facecolor',[0.4,0.4,0.4],'edgecolor',[0.75,0.75,0.75])
hold on
title('LEH')
mylegend=legend('Daily MES','Daily SRISK ($ bln)','Rejection dates');
set(mylegend,'FontSize',8);
ylim([0 150])
suptitle('Figure 18: IND backtests for one-day risk forecast horizon (rolling estimation, T = 500, n = 500,m = 5)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 19 of the paper (appendix J)      ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_rolling_T=500_N=250
level=0.05;                                                % Rejection threshold of null hypothesis
% UC tests :
m_uc_c=nb_firm-sum(isnan(p_uc_c),2);
m_uc_c_kernel=nb_firm-sum(isnan(p_uc_c_kernel),2);
% Rejection rate for uc test with bonferonni controling method
bonf_reject_rate_uc_c_kernel=sum(repmat(m_uc_c_kernel,1,nb_firm).*p_uc_c_kernel<level,2)./(nb_firm-sum(isnan(p_uc_c_kernel),2));
subplot(2,1,1)
bar(date,bonf_reject_rate_uc_c_kernel)
ylim([0 1])
grid on
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([datenum(first_year,1,2) datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
title('UC test')
lag=5;                                                     % Lag choice for the IND test
level=0.05;                                                % Rejection threshold of null hypothesis
% Number of firms's individual tests (belonging to the joint test)
% Ind tests :
m_ind_c_kernel=nb_firm-sum(isnan(p_ind_c_kernel(:,:,lag)),2);
% Rejection rate for ind test with bonferonni controling method
bonf_reject_rate_ind_c_kernel=sum(repmat(m_ind_c_kernel,1,nb_firm).*p_ind_c_kernel(:,:,lag)<level,2)./(nb_firm-sum(isnan(p_ind_c_kernel(:,:,lag)),2));
subplot(2,1,2)
bar(date,bonf_reject_rate_ind_c_kernel)
ylim([0 1])
grid on
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([datenum(first_year,1,2) datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
title('IND test')
suptitle('Figure 19: Rejection rates of UC and IND backtests (rolling estimation, T = 500, n = 250, m = 5)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

%=========================================================%
%======    Figure 20 of the paper (appendix J)      ======%
%=========================================================%

clear ; clc ;
load historical_rejection_rate_rolling_T=500_N=500
level=0.05;                                                % Rejection threshold of null hypothesis
% UC tests :
m_uc_c=nb_firm-sum(isnan(p_uc_c),2);
m_uc_c_kernel=nb_firm-sum(isnan(p_uc_c_kernel),2);
% Rejection rate for uc test with bonferonni controling method
bonf_reject_rate_uc_c_kernel=sum(repmat(m_uc_c_kernel,1,nb_firm).*p_uc_c_kernel<level,2)./(nb_firm-sum(isnan(p_uc_c_kernel),2));
subplot(2,1,1)
bar(date,bonf_reject_rate_uc_c_kernel)
ylim([0 1])
grid on
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([datenum(first_year,1,2) datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
title('UC test')
lag=5;                                                     % Lag choice for the IND test
level=0.05;                                                % Rejection threshold of null hypothesis
% Number of firms's individual tests (belonging to the joint test)
% Ind tests :
m_ind_c_kernel=nb_firm-sum(isnan(p_ind_c_kernel(:,:,lag)),2);
% Rejection rate for ind test with bonferonni controling method
bonf_reject_rate_ind_c_kernel=sum(repmat(m_ind_c_kernel,1,nb_firm).*p_ind_c_kernel(:,:,lag)<level,2)./(nb_firm-sum(isnan(p_ind_c_kernel(:,:,lag)),2));
subplot(2,1,2)
bar(date,bonf_reject_rate_ind_c_kernel)
ylim([0 1])
grid on
legend(sprintf('Rejection rate at %1.2f level',level))
xlim([datenum(first_year,1,2) datenum(last_year+1,2,2)])
ax = gca;ax.XTick = datenum(first_year:last_year+1,2,2);
datetick('x','yyyy','keeplimits','keepticks')
title('IND test')
suptitle('Figure 20: Rejection rates of UC and IND backtests (rolling estimation, T = 500, n = 500, m = 5)')
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0, 0.2, 1, 0.7]);

