%-------------------------------------------------------------------------------------
% PURPOSE: Constrained log-Likelihood of a multivariate normal sample
%-------------------------------------------------------------------------------------
%   Inputs:
%           - theta  = [var1;rho;var2] , vector (3,1) of var-covariance parameters
%           - Y: vector(T,2) of realisations
%           - constraint = 1 if var1 is constrained, 2 if rho is contrained
%           and 3 if var2 is constrained
%           - value : value of the constrained parameter
%  Output:  
%         -   lik = opposite of the log-likelihood
%-------------------------------------------------------------------------------------
% J. Leymarie, C. Hurlin. April 26, 2016.
% LEO, University of Orleans
%-------------------------------------------------------------------------------------

function lik=loglikelihood_normal_cons(theta,Y,constraint,value)

if constraint==1
    
    S=[value sqrt(value *theta(2))*theta(1) ; sqrt(value*theta(2))*theta(1) theta(2)];
    
elseif constraint==2
    
    S=[theta(1) sqrt(theta(1)*value)*theta(2); sqrt(theta(1)*value)*theta(2) value];
        
elseif constraint==3
    
    S=[theta(1) sqrt(theta(1)*theta(2))*value ; sqrt(theta(1)*theta(2))*value theta(2)];
    
end

lik=-sum(log(mvnpdf(Y,0,S)));

